package com.seeyon.ctp.rest.resources.util;

import java.io.ByteArrayInputStream;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;
import org.xml.sax.InputSource;

import com.seeyon.apps.govdoc.helper.GovdocAffairHelper;
import com.seeyon.apps.govdoc.listener.GovdocWorkflowEventListener;
import com.seeyon.apps.govdoc.manager.GovdocContinueManager;
import com.seeyon.apps.govdoc.manager.GovdocExchangeManager;
import com.seeyon.apps.govdoc.manager.GovdocPishiManager;
import com.seeyon.apps.govdoc.manager.GovdocWorkflowManager;
import com.seeyon.apps.govdoc.mark.manager.GovdocMarkManager;
import com.seeyon.apps.govdoc.po.GovdocExchangeDetail;
import com.seeyon.apps.govdoc.po.GovdocExchangeMain;
import com.seeyon.apps.govdoc.vo.GovdocRepealVO;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.GlobalNames;
import com.seeyon.ctp.common.affair.enums.AffairExtPropEnums;
import com.seeyon.ctp.common.affair.manager.AffairManager;
import com.seeyon.ctp.common.affair.util.AffairUtil;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.constants.ApplicationSubCategoryEnum;
import com.seeyon.ctp.common.content.affair.AffairData;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.common.log.CtpLogFactory;
import com.seeyon.ctp.common.po.affair.CtpAffair;
import com.seeyon.ctp.common.po.template.CtpTemplate;
import com.seeyon.ctp.util.DBAgent;
import com.seeyon.ctp.util.FlipInfo;
import com.seeyon.ctp.util.JDBCAgent;
import com.seeyon.ctp.util.Strings;
import com.seeyon.v3x.edoc.domain.EdocSummary;
import com.seeyon.v3x.edoc.util.StringUtils;


public class EdocResourceUtil {
	private static Log LOGGER = CtpLogFactory.getLog(EdocResourceUtil.class);
	private final static EdocResourceUtil INSTANCE = new EdocResourceUtil();
	private final static String DBTYPE = getDbType();
	private GovdocWorkflowManager govdocWorkflowManager = (GovdocWorkflowManager)AppContext.getBean("govdocWorkflowManager");
	private GovdocExchangeManager govdocExchangeManager = (GovdocExchangeManager)AppContext.getBean("govdocExchangeManager");
	private GovdocContinueManager govdocContinueManager = (GovdocContinueManager)AppContext.getBean("govdocContinueManager");
	private GovdocPishiManager govdocPishiManager = (GovdocPishiManager)AppContext.getBean("govdocPishiManager");
	private GovdocMarkManager govdocMarkManager = (GovdocMarkManager) AppContext.getBean("govdocMarkManager");
	private AffairManager affairManager = (AffairManager)AppContext.getBean("affairManager");
	public final static EdocResourceUtil getInstance() {
		return INSTANCE;
	}

	private static final List<String> mysqlAndSqlServerOrderListForTemplate = new ArrayList<String>() {
		{
			add("delete cpl from ctp_process_log cpl, edoc_summary es where cpl.process_id = es.process_id and es.templete_id = ?");
			add("delete ess from edoc_supervisor ess, edoc_supervise_detail esd, edoc_summary es where ess.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?");
			add("delete esl from edoc_supervise_log esl, edoc_supervise_detail esd, edoc_summary es where esl.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?");
			add("delete esr from edoc_supervise_remind esr, edoc_supervise_detail esd, edoc_summary es where esr.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?");
			add("delete dl from doc_learning dl, doc_resources dr, ctp_affair ca, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete df from doc_favorites df, doc_resources dr, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = es.id and es.templete_id = ?");
			add("delete df from doc_favorites df, doc_resources dr, ctp_affair ca, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete cuhm from ctp_user_history_message cuhm, doc_resources dr, ctp_affair ca, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete drm from doc_resources drm, doc_resources dr, ctp_affair ca, edoc_summary es where drm.source_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete cum from ctp_user_message cum, doc_resources dr, ctp_affair ca, edoc_summary es where cum.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete cuhm from ctp_user_history_message cuhm, doc_resources dr, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = es.id and es.templete_id = ?");
			add("delete cum from ctp_user_message cum, doc_resources dr, edoc_summary es where cum.reference_id = dr.id and dr.source_id = es.id and es.templete_id = ?");
			add("delete dl from doc_learning dl, doc_resources dr, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = es.id and es.templete_id = ?");
			add("delete drm from doc_resources drm, doc_resources dr, edoc_summary es where drm.source_id = dr.id and dr.source_id = es.id and es.templete_id = ?");
			add("delete csr from ctp_supervise_receiver csr, ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary es where csr.log_id = csl.id and csl.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?");
			add("delete css from ctp_supervisor css, ctp_supervise_detail csd, edoc_summary es where css.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?");
			add("delete csl from ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary es where csl.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?");
			add("delete cuhm from ctp_user_history_message cuhm, ctp_supervise_detail csd, edoc_summary es where cuhm.reference_id = csd.id and csd.entity_id = es.id and es.templete_id = ?");
			add("delete cum from ctp_user_message cum, ctp_supervise_detail csd, edoc_summary es where cum.reference_id = csd.id and csd.entity_id = es.id and es.templete_id = ?");
			add("delete wwr from wf_workitem_run wwr, edoc_summary es, ctp_affair ca where wwr.id = ca.sub_object_id and ca.object_id = es.id and es.templete_id = ?");
			add("delete wcr from wf_case_run wcr, edoc_summary es where wcr.id = es.case_id and es.templete_id = ?");
			add("delete wch from wf_case_history wch, edoc_summary es where wch.id = es.case_id and es.templete_id = ?");
			add("delete cuhm from ctp_user_history_message cuhm, ctp_affair ca, edoc_summary es where cuhm.reference_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete dr from doc_resources dr, ctp_affair ca, edoc_summary es where dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete cum from ctp_user_message cum, ctp_affair ca, edoc_summary es where cum.reference_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete wpr from wf_process_running wpr, edoc_summary es where wpr.id = es.process_id and es.templete_id = ?");
			add("delete eo from edoc_opinion eo, edoc_summary es where eo.edoc_id = es.id and es.templete_id = ?");
			add("delete est from edoc_stat est, edoc_summary es where est.edoc_id = es.id and es.templete_id = ?");
			add("delete gr from govdoc_register gr, edoc_summary es where gr.summary_id = es.id and es.templete_id = ?");
			add("delete cwt from ctp_workflow_track cwt, edoc_summary es where cwt.module_id = es.id and es.templete_id = ?");
			add("delete gedl from govdoc_exchange_detail_log gedl, govdoc_exchange_detail ged, govdoc_exchange_main gem, edoc_summary es where gedl.detail_id = ged.id and ged.main_id = gem.id and gem.summary_id = es.id and es.templete_id = ?");
			add("delete ged from govdoc_exchange_detail ged, govdoc_exchange_main gem, edoc_summary es where ged.main_id = gem.id and gem.summary_id = es.id and es.templete_id = ?");
			add("delete gem from govdoc_exchange_main gem, edoc_summary es where gem.summary_id = es.id and es.templete_id = ?");
			//add("delete em from edoc_mark em, edoc_summary es where em.edoc_id = es.id and es.templete_id = ?");
			add("delete gmr from govdoc_mark_record gmr, edoc_summary es where gmr.summary_id = es.id and es.templete_id = ?");
			add("delete emh from edoc_mark_history emh, edoc_summary es where emh.edoc_id = es.id and es.templete_id = ?");
			add("delete esd from edoc_supervise_detail esd, edoc_summary es where esd.edoc_id = es.id and es.templete_id = ?");
			add("delete esr from edoc_summary_relation esr, edoc_summary es where esr.summary_id = es.id and es.templete_id = ?");
			add("delete dr from doc_resources dr, edoc_summary es where dr.source_id = es.id and es.templete_id = ?");
			add("delete dr from doc_resources dr, edoc_summary es,ctp_affair ca where dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?");
			add("delete elpn from edoc_leader_pishi_no elpn, edoc_summary es where elpn.summary_id = es.id and es.templete_id = ?");
			add("delete ese from edoc_summary_extend ese, edoc_summary es where ese.summary_id = es.id and es.templete_id = ?");
			add("delete csd from ctp_supervise_detail csd, edoc_summary es where csd.entity_id = es.id and es.templete_id = ?");
			add("delete cca from ctp_comment_all cca, edoc_summary es where cca.module_id = es.id and es.templete_id = ?");
			// add("delete cca from ctp_content_all cca, edoc_summary es where cca.module_id
			// = es.id and es.templete_id = ?");
			add("delete gwr from govdoc_wpstrans_record gwr, ctp_affair ca,edoc_summary es where ca.object_id = es.id and gwr.affair_id = ca.id and es.templete_id = ?");
			add("delete ca from ctp_affair ca, edoc_summary es where ca.object_id = es.id and es.templete_id = ?");
			add("delete from edoc_summary where templete_id = ?");
		}
	};

	private static final List<String> oracleOrderListForTemplate = new ArrayList<String>() {
		{
			add("delete from ctp_process_log cpl WHERE EXISTS (select 1 from edoc_summary es where cpl.process_id = es.process_id and es.templete_id = ?)");
			add("delete from edoc_supervisor ess WHERE EXISTS (select 1 from edoc_supervise_detail esd, edoc_summary es where ess.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?)");
			add("delete from edoc_supervise_log esl WHERE EXISTS (select 1 from edoc_supervise_detail esd, edoc_summary es where esl.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?)");
			add("delete from edoc_supervise_remind esr WHERE EXISTS (select 1 from edoc_supervise_detail esd, edoc_summary es where esr.supervise_id = esd.id and esd.edoc_id = es.id and es.templete_id = ?)");
			add("delete from doc_learning dl WHERE EXISTS (select 1 from doc_resources dr, ctp_affair ca, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from doc_favorites df WHERE EXISTS (select 1 from doc_resources dr, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_history_message cuhm WHERE EXISTS (select 1 from doc_resources dr, ctp_affair ca, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from doc_favorites df WHERE EXISTS (select 1 from doc_resources dr, ctp_affair ca, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from doc_resources drm WHERE EXISTS (select 1 from doc_resources dr, ctp_affair ca, edoc_summary es where drm.source_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_message cum WHERE EXISTS (select 1 from doc_resources dr, ctp_affair ca, edoc_summary es where cum.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_history_message cuhm WHERE EXISTS (select 1 from doc_resources dr, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_message cum WHERE EXISTS (select 1 from doc_resources dr, edoc_summary es where cum.reference_id = dr.id and dr.source_id = es.id and es.templete_id = ?)");
			add("delete from doc_learning dl WHERE EXISTS (select 1 from doc_resources dr, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = es.id and es.templete_id = ?)");
			add("delete from doc_resources drm WHERE EXISTS (select 1 from doc_resources dr, edoc_summary es where drm.source_id = dr.id and dr.source_id = es.id and es.templete_id = ?)");
			add("delete from ctp_supervise_receiver csr WHERE EXISTS (select 1 from ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary es where csr.log_id = csl.id and csl.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from ctp_supervisor css WHERE EXISTS (select 1 from ctp_supervise_detail csd, edoc_summary es where css.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from ctp_supervise_log csl WHERE EXISTS (select 1 from ctp_supervise_detail csd, edoc_summary es where csl.supervise_id = csd.id and csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_history_message cuhm WHERE EXISTS (select 1 from ctp_supervise_detail csd, edoc_summary es where cuhm.reference_id = csd.id and csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_message cum WHERE EXISTS (select 1 from ctp_supervise_detail csd, edoc_summary es where cum.reference_id = csd.id and csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from wf_workitem_run wwr WHERE EXISTS (select 1 from edoc_summary es, ctp_affair ca where wwr.id = ca.sub_object_id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from wf_case_run wcr WHERE EXISTS (select 1 from edoc_summary es where wcr.id = es.case_id and es.templete_id = ?)");
			add("delete from wf_case_history wch WHERE EXISTS (select 1 from edoc_summary es where wch.id = es.case_id and es.templete_id = ?)");
			add("delete from ctp_user_history_message cuhm WHERE EXISTS (select 1 from ctp_affair ca, edoc_summary es where cuhm.reference_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from doc_resources dr WHERE EXISTS (select 1 from ctp_affair ca, edoc_summary es where dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from ctp_user_message cum WHERE EXISTS (select 1 from ctp_affair ca, edoc_summary es where cum.reference_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from wf_process_running wpr WHERE EXISTS (select 1 from edoc_summary es where wpr.id = es.process_id and es.templete_id = ?)");
			add("delete from edoc_opinion eo WHERE EXISTS (select 1 from edoc_summary es where eo.edoc_id = es.id and es.templete_id = ?)");
			add("delete from edoc_stat est WHERE EXISTS (select 1 from edoc_summary es where est.edoc_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_register gr WHERE EXISTS (select 1 from edoc_summary es where gr.summary_id = es.id and es.templete_id = ?)");
			add("delete from ctp_workflow_track cwt WHERE EXISTS (select 1 from edoc_summary es where cwt.module_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_exchange_detail_log gedl WHERE EXISTS (select 1 from govdoc_exchange_detail ged, govdoc_exchange_main gem, edoc_summary es where gedl.detail_id = ged.id and ged.main_id = gem.id and gem.summary_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_exchange_detail ged WHERE EXISTS (select 1 from govdoc_exchange_main gem, edoc_summary es where ged.main_id = gem.id and gem.summary_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_exchange_main gem WHERE EXISTS (select 1 from edoc_summary es where gem.summary_id = es.id and es.templete_id = ?)");
			//add("delete from edoc_mark em WHERE EXISTS (select 1 from edoc_summary es where em.edoc_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_mark_record gmr WHERE EXISTS (select 1 from edoc_summary es where gmr.summary_id = es.id and es.templete_id = ?)");
			add("delete from edoc_mark_history emh WHERE EXISTS (select 1 from edoc_summary es where emh.edoc_id = es.id and es.templete_id = ?)");
			add("delete from edoc_supervise_detail esd WHERE EXISTS (select 1 from edoc_summary es where esd.edoc_id = es.id and es.templete_id = ?)");
			add("delete from edoc_summary_relation esr WHERE EXISTS (select 1 from edoc_summary es where esr.summary_id = es.id and es.templete_id = ?)");
			add("delete from doc_resources dr WHERE EXISTS (select 1 from edoc_summary es where dr.source_id = es.id and es.templete_id = ?)");
			add("delete from doc_resources dr WHERE EXISTS (select 1 from edoc_summary es,ctp_affair ca where dr.source_id = ca.id and ca.object_id = es.id and es.templete_id = ?)");
			add("delete from edoc_leader_pishi_no elpn WHERE EXISTS (select 1 from edoc_summary es where elpn.summary_id = es.id and es.templete_id = ?)");
			add("delete from edoc_summary_extend ese WHERE EXISTS (select 1 from edoc_summary es where ese.summary_id = es.id and es.templete_id = ?)");
			add("delete from ctp_supervise_detail csd WHERE EXISTS (select 1 from edoc_summary es where csd.entity_id = es.id and es.templete_id = ?)");
			add("delete from ctp_comment_all cca WHERE EXISTS (select 1 from edoc_summary es where cca.module_id = es.id and es.templete_id = ?)");
			add("delete from ctp_content_all cca WHERE EXISTS (select 1 from edoc_summary es where cca.module_id = es.id and es.templete_id = ?)");
			add("delete from govdoc_wpstrans_record gwr WHERE EXISTS (select 1 from ctp_affair ca,edoc_summary es where ca.object_id = es.id and gwr.affair_id = ca.id and es.templete_id = ?)");
			add("delete from ctp_affair affair WHERE EXISTS (select 1 from edoc_summary es where affair.object_id = es.id and es.templete_id = ?)");
			add("delete from edoc_summary where templete_id = ?");
		}
	};

	private static final List<String> mysqlAndSqlServerOrderListForSummary = new ArrayList<String>() {
		{
			add("delete cpl from ctp_process_log cpl, edoc_summary es where cpl.process_id = es.process_id and es.id in (?)");
			add("delete ess from edoc_supervisor ess, edoc_supervise_detail esd, edoc_summary es where ess.supervise_id = esd.id and esd.edoc_id = es.id and es.id in (?)");
			add("delete esl from edoc_supervise_log esl, edoc_supervise_detail esd, edoc_summary es where esl.supervise_id = esd.id and esd.edoc_id = es.id and es.id in (?)");
			add("delete esr from edoc_supervise_remind esr, edoc_supervise_detail esd, edoc_summary es where esr.supervise_id = esd.id and esd.edoc_id = es.id and es.id in (?)");
			add("delete dl from doc_learning dl, doc_resources dr, ctp_affair ca, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete df from doc_favorites df, doc_resources dr, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = es.id and es.id in (?)");
			add("delete df from doc_favorites df, doc_resources dr, ctp_affair ca, edoc_summary es where df.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete cuhm from ctp_user_history_message cuhm, doc_resources dr, ctp_affair ca, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete drm from doc_resources drm, doc_resources dr, ctp_affair ca, edoc_summary es where drm.source_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete cum from ctp_user_message cum, doc_resources dr, ctp_affair ca, edoc_summary es where cum.reference_id = dr.id and dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete cuhm from ctp_user_history_message cuhm, doc_resources dr, edoc_summary es where cuhm.reference_id = dr.id and dr.source_id = es.id and es.id in (?)");
			add("delete cum from ctp_user_message cum, doc_resources dr, edoc_summary es where cum.reference_id = dr.id and dr.source_id = es.id and es.id in (?)");
			add("delete dl from doc_learning dl, doc_resources dr, edoc_summary es where dl.doc_resource_id = dr.id and dr.source_id = es.id and es.id in (?)");
			add("delete drm from doc_resources drm, doc_resources dr, edoc_summary es where drm.source_id = dr.id and dr.source_id = es.id and es.id in (?)");
			add("delete csr from ctp_supervise_receiver csr, ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary es where csr.log_id = csl.id and csl.supervise_id = csd.id and csd.entity_id = es.id and es.id in (?)");
			add("delete css from ctp_supervisor css, ctp_supervise_detail csd, edoc_summary es where css.supervise_id = csd.id and csd.entity_id = es.id and es.id in (?)");
			add("delete csl from ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary es where csl.supervise_id = csd.id and csd.entity_id = es.id and es.id in (?)");
			add("delete cuhm from ctp_user_history_message cuhm, ctp_supervise_detail csd, edoc_summary es where cuhm.reference_id = csd.id and csd.entity_id = es.id and es.id in (?)");
			add("delete cum from ctp_user_message cum, ctp_supervise_detail csd, edoc_summary es where cum.reference_id = csd.id and csd.entity_id = es.id and es.id in (?)");
			add("delete wwr from wf_workitem_run wwr, edoc_summary es, ctp_affair ca where wwr.id = ca.sub_object_id and ca.object_id = es.id and es.id in (?)");
			add("delete wcr from wf_case_run wcr, edoc_summary es where wcr.id = es.case_id and es.id in (?)");
			add("delete wch from wf_case_history wch, edoc_summary es where wch.id = es.case_id and es.id in (?)");
			add("delete cuhm from ctp_user_history_message cuhm, ctp_affair ca, edoc_summary es where cuhm.reference_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete dr from doc_resources dr, ctp_affair ca, edoc_summary es where dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete cum from ctp_user_message cum, ctp_affair ca, edoc_summary es where cum.reference_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete wpr from wf_process_running wpr, edoc_summary es where wpr.id = es.process_id and es.id in (?)");
			add("delete eo from edoc_opinion eo, edoc_summary es where eo.edoc_id = es.id and es.id in (?)");
			add("delete est from edoc_stat est, edoc_summary es where est.edoc_id = es.id and es.id in (?)");
			add("delete gr from govdoc_register gr, edoc_summary es where gr.summary_id = es.id and es.id in (?)");
			add("delete cwt from ctp_workflow_track cwt, edoc_summary es where cwt.module_id = es.id and es.id in (?)");
			add("delete gedl from govdoc_exchange_detail_log gedl, govdoc_exchange_detail ged, govdoc_exchange_main gem, edoc_summary es where gedl.detail_id = ged.id and ged.main_id = gem.id and gem.summary_id = es.id and es.id in (?)");
			add("delete ged from govdoc_exchange_detail ged, govdoc_exchange_main gem, edoc_summary es where ged.main_id = gem.id and gem.summary_id = es.id and es.id in (?)");
			add("delete gem from govdoc_exchange_main gem, edoc_summary es where gem.summary_id = es.id and es.id in (?)");
			//add("delete em from edoc_mark em, edoc_summary es where em.edoc_id = es.id and es.id in (?)");
			add("delete gmr from govdoc_mark_record gmr, edoc_summary es where gmr.summary_id = es.id and es.id in (?)");
			add("delete emh from edoc_mark_history emh, edoc_summary es where emh.edoc_id = es.id and es.id in (?)");
			add("delete esd from edoc_supervise_detail esd, edoc_summary es where esd.edoc_id = es.id and es.id in (?)");
			add("delete esr from edoc_summary_relation esr, edoc_summary es where esr.summary_id = es.id and es.id in (?)");
			add("delete dr from doc_resources dr, edoc_summary es where dr.source_id = es.id and es.id in (?)");
			add("delete dr from doc_resources dr, edoc_summary es,ctp_affair ca where dr.source_id = ca.id and ca.object_id = es.id and es.id in (?)");
			add("delete elpn from edoc_leader_pishi_no elpn, edoc_summary es where elpn.summary_id = es.id and es.id in (?)");
			add("delete ese from edoc_summary_extend ese, edoc_summary es where ese.summary_id = es.id and es.id in (?)");
			add("delete csd from ctp_supervise_detail csd, edoc_summary es where csd.entity_id = es.id and es.id in (?)");
			add("delete cca from ctp_comment_all cca, edoc_summary es where cca.module_id = es.id and es.id in (?)");
			add("delete cca from ctp_content_all cca, edoc_summary es where cca.module_id = es.id and es.id in (?)");
			add("delete gwr from govdoc_wpstrans_record gwr, ctp_affair ca,edoc_summary es where ca.object_id = es.id and gwr.affair_id = ca.id and es.id in (?)");
			add("delete ca from ctp_affair ca, edoc_summary es where ca.object_id = es.id and es.id in (?)");
			add("delete from edoc_summary where id in (?)");
		}
	};

	private static final List<String> oracleOrderListForSummary = new ArrayList<String>() {
		{
			add("delete from ctp_process_log cpl where exists (select 1 from edoc_summary es where cpl.process_id = es.process_id and es.id in (?))");
			add("delete from edoc_supervisor ess where exists (select 1 from edoc_supervise_detail esd where ess.supervise_id = esd.id and esd.edoc_id in (?))");
			add("delete from edoc_supervise_log esl where exists (select 1 from edoc_supervise_detail esd where esl.supervise_id = esd.id and esd.edoc_id in (?))");
			add("delete from edoc_supervise_remind esr where exists (select 1 from edoc_supervise_detail esd where esr.supervise_id = esd.id and esd.edoc_id in (?))");
			add("delete from doc_learning dl where exists (select 1 from doc_resources dr, ctp_affair ca where dl.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from doc_favorites df where exists (select 1 from doc_resources dr where df.doc_resource_id = dr.id and dr.source_id in (?))");
			add("delete from ctp_user_history_message cuhm where exists (select 1 from doc_resources dr, ctp_affair ca where cuhm.reference_id = dr.id and dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from doc_favorites df where exists (select 1 from doc_resources dr, ctp_affair ca where df.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from doc_resources drm where exists (select 1 from doc_resources dr, ctp_affair ca where drm.source_id = dr.id and dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from ctp_user_message cum where exists (select 1 from doc_resources dr, ctp_affair ca where cum.reference_id = dr.id and dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from ctp_user_history_message cuhm where exists (select 1 from doc_resources dr where cuhm.reference_id = dr.id and dr.source_id in (?))");
			add("delete from ctp_user_message cum where exists (select 1 from doc_resources dr where cum.reference_id = dr.id and dr.source_id in (?))");
			add("delete from doc_learning dl where exists (select 1 from doc_resources dr where dl.doc_resource_id = dr.id and dr.source_id in (?))");
			add("delete from doc_resources drm where exists (select 1 from doc_resources dr where drm.source_id = dr.id and dr.source_id in (?))");
			add("delete from ctp_supervise_receiver csr where exists (select 1 from ctp_supervise_log csl, ctp_supervise_detail csd where csr.log_id = csl.id and csl.supervise_id = csd.id and csd.entity_id in (?))");
			add("delete from ctp_supervisor css where exists (select 1 from ctp_supervise_detail csd where css.supervise_id = csd.id and csd.entity_id in  (?))");
			add("delete from ctp_supervise_log csl where exists (select 1 from ctp_supervise_detail csd where csl.supervise_id = csd.id and csd.entity_id in  (?))");
			add("delete from ctp_user_history_message cuhm where exists (select 1 from ctp_supervise_detail csd where cuhm.reference_id = csd.id and csd.entity_id in  (?))");
			add("delete from ctp_user_message cum where exists (select 1 from ctp_supervise_detail csd where cum.reference_id = csd.id and csd.entity_id in (?))");
			add("delete from wf_workitem_run wwr where exists (select 1 from ctp_affair ca where wwr.id = ca.sub_object_id and ca.object_id in (?))");
			add("delete from wf_case_run wcr where exists (select 1 from edoc_summary es where wcr.id = es.case_id and es.id in (?))");
			add("delete from wf_case_history wch where exists (select 1  from edoc_summary es where wch.id = es.case_id and es.id in  (?))");
			add("delete from ctp_user_history_message cuhm where exists (select 1 from ctp_affair ca where cuhm.reference_id = ca.id and ca.object_id in (?))");
			add("delete from ctp_user_message cum where exists (select 1  from ctp_affair ca where cum.reference_id = ca.id and ca.object_id in (?))");
			add("delete from wf_process_running wpr where exists (select 1 from edoc_summary es where wpr.id = es.process_id and es.id in (?))");
			add("delete from edoc_opinion where edoc_id in (?)");
			add("delete from edoc_stat where edoc_id in (?)");
			add("delete from govdoc_register where summary_id in (?)");
			add("delete from ctp_workflow_track where module_id in (?)");
			add("delete from govdoc_exchange_detail_log log where exists (select 1 from govdoc_exchange_detail detail, govdoc_exchange_main main where log.detail_id = detail.id and detail.main_id = main.id and main.summary_id in (?))");
			add("delete from govdoc_exchange_detail detail where exists (select 1 from govdoc_exchange_main main where detail.main_id = main.id and main.summary_id in (?))");
			add("delete from govdoc_exchange_main where summary_id in (?)");
			//add("delete from edoc_mark where edoc_id in (?)");
			add("delete from govdoc_mark_record where summary_id in (?)");
			add("delete from edoc_mark_history where edoc_id in (?)");
			add("delete from edoc_supervise_detail where edoc_id in (?)");
			add("delete from edoc_summary_relation where summary_id in (?)");
			add("delete from doc_resources where source_id in (?)");
			add("delete from doc_resources dr where exists (select 1 from ctp_affair ca where dr.source_id = ca.id and ca.object_id in (?))");
			add("delete from edoc_leader_pishi_no where summary_id in (?)");
			add("delete from edoc_summary_extend where summary_id in (?)");
			add("delete from ctp_supervise_detail where entity_id in (?)");
			add("delete from ctp_comment_all where module_id in (?)");
			add("delete from ctp_content_all where module_id in (?)");
			add("delete from govdoc_wpstrans_record gwr where exists (select 1 from ctp_affair ca where gwr.affair_id = ca.id and ca.object_id in (?))");
			add("delete from ctp_affair where object_id in (?)");

		}
	};

	public void deleteEdocDataByTemplate(Object obj, Integer needDelRec) throws Exception {
		LOGGER.info("进入删除公文数据逻辑");
		// 如果传入的是模板对象，根据模板删除相关数据
		if (obj instanceof CtpTemplate) {
			CtpTemplate template = (CtpTemplate) obj;
			int tempModuleType = template.getModuleType();
			if (tempModuleType != 401 && tempModuleType != 402 && tempModuleType != 403 && tempModuleType != 404) {
				LOGGER.warn("传入的模板ID不属于公文，清除任务取消");
				return;
			}
			LOGGER.info(
					"根据模板删除公文数据，开始-------------------，模板id=" + template.getId() + ", 模板名称:" + template.getSubject());
			List<Object> tempalteParam = new ArrayList<Object>();
			tempalteParam.add(template.getId());

			// 查询出交换相关的mainId
			String exchangeMainIdSql = "select gem.id from edoc_summary es,govdoc_exchange_main gem where es.id = gem.summary_id and es.templete_id = ?";
			List<Map<String, Object>> exchangeMainIds = exeQuerySource(exchangeMainIdSql, tempalteParam);
			String mainIds = installIdToString(exchangeMainIds, "id");
			if (!Strings.isBlank(mainIds)) {
				StringBuilder needDelSummaryIds = new StringBuilder();
				// 处理生成的签收数据ID
				String signSummaryIdsSql = "select summary_id from govdoc_exchange_detail where summary_id is not null and main_id in ("
						+ "select gem.id from edoc_summary es,govdoc_exchange_main gem where es.id = gem.summary_id and es.templete_id = ?)";
				List<Map<String, Object>> signSummaryIds = exeQuerySource(signSummaryIdsSql, tempalteParam);
				String signIds = installIdToString(signSummaryIds, "summary_id");
				needDelSummaryIds.append(signIds);

				if (needDelRec == 1) {
					// 处理生成的收文数据ID
					String recSummaryIdsSql = "select rec_summary_id from govdoc_exchange_detail where rec_summary_id is not null and main_id in ("
							+ "select gem.id from edoc_summary es,govdoc_exchange_main gem where es.id = gem.summary_id and es.templete_id = ?)";
					List<Map<String, Object>> recSummaryIds = exeQuerySource(recSummaryIdsSql, tempalteParam);
					String recIds = installIdToString(recSummaryIds, "rec_summary_id");
					needDelSummaryIds.append(",").append(recIds);
				}
				if (!Strings.isBlank(needDelSummaryIds.toString())) {
					List<Map<String, Object>> formIdAndSummaryId = getSummaryFormIdAndSummaryId(
							needDelSummaryIds.toString());
					deleteEdocDataBySummary(formIdAndSummaryId);
				}

			}

			//删除主表记录
			delFormmainByFormIdAndObjectId(template.getFormAppId(),template.getId(),1);
			
			//删除设置的超期任务 
			delJKTask(template.getId(),1);
			
			//删除公文相关的其他数据 
			if(DBTYPE.indexOf("oracle") > -1){
				exeBulkDelQuery(oracleOrderListForTemplate,tempalteParam); 
			}else if(DBTYPE.indexOf("mysql") > -1 || DBTYPE.indexOf("sqlserver") > -1){
				exeBulkDelQuery(mysqlAndSqlServerOrderListForTemplate,tempalteParam);
			}else{//兼容 达梦 等其他数据库 据说和sqlserver相同
				exeBulkDelQuery(mysqlAndSqlServerOrderListForTemplate,tempalteParam); 
			}
			
			LOGGER.info("根据模板删除公文数据，结束-------------------");
			
		}
	}

	public void deleteEdocDataBySummary(List<Map<String, Object>> objs) throws Exception {
		LOGGER.info("根据功能我给你ID删除公文数据，开始-------------------");
		if (objs.isEmpty()) {
			LOGGER.info("根据公文ID删除公文数据，结束-------------------");
			return;
		}
		StringBuilder summaryIds = new StringBuilder();
		for (int i = 0; i < objs.size(); i++) {

			// 删除主表记录
			delFormmainByFormIdAndObjectId(Long.valueOf(objs.get(i).get("form_app_id").toString()), Long.valueOf(objs.get(i).get("id").toString()), 2);

			// 删除设置的超期任务
			delJKTask(Long.valueOf(objs.get(i).get("id").toString()), 2);

			summaryIds.append(Long.valueOf(objs.get(i).get("id").toString()));
			if (i + 1 < objs.size()) {
				summaryIds.append(",");
			}
		}

		// 删除公文相关的其他数据
		if (DBTYPE.indexOf("oracle") > -1) {
			exeBulkDelQueryForIn(oracleOrderListForSummary, summaryIds.toString());
		} else if (DBTYPE.indexOf("mysql") > -1 || DBTYPE.indexOf("sqlserver") > -1) {
			exeBulkDelQueryForIn(mysqlAndSqlServerOrderListForSummary, summaryIds.toString());
		} else {// 兼容 达梦 等其他数据库 据说和sqlserver相同
			exeBulkDelQueryForIn(mysqlAndSqlServerOrderListForSummary, summaryIds.toString());
		}

		LOGGER.info("根据公文ID删除公文数据，结束-------------------");

	}

	/**
	 * 删除动态表数据
	 * 
	 * @param formId 表单ID
	 * @param objId  需要删除的数据ID
	 * @param type   删除的类型1 根据模板ID删除，2 根据SummaryId删除
	 * @return
	 * @throws Exception
	 */
	private void delFormmainByFormIdAndObjectId(Long formId, Long objId, int type) throws Exception {
		// 动态表名称
		String tableName = "";
		String formSql = "select field_info from form_definition where id = ?";
		List<Object> formParams = new ArrayList<Object>();
		formParams.add(formId);
		List<Map<String, Object>> fieldInfos = exeQuerySource(formSql, formParams);
		for (Map<String, Object> fieldInfo : fieldInfos) {
			String info = (String) fieldInfo.get("field_info");
			Element root = getRootElementByString(info);
			Element tableElement = root.element("Table");
			tableName = tableElement.attributeValue("name");
		}

		if (Strings.isNotBlank(tableName)) {
			StringBuilder selectFmMysqlSqlServerSql = new StringBuilder();
			StringBuilder selectFmOracleSql = new StringBuilder();
			
			selectFmMysqlSqlServerSql.append("select fm.id from ").append(tableName)
			.append(" fm, edoc_summary es where fm.id = es.form_recordid ");
			selectFmOracleSql.append("select fm.id from ").append(tableName).append(" fm where exists (select 1 from edoc_summary es where fm.id = es.form_recordid ");
			if (type == 1) {
				selectFmMysqlSqlServerSql.append("and es.templete_id = ?");
				selectFmOracleSql.append(" and es.templete_id = ?)");
			} else {
				selectFmMysqlSqlServerSql.append("and es.id = ?");
				selectFmOracleSql.append("and es.id = ?)");
			}
			
			List<Object> param = new ArrayList<Object>();
			param.add(objId);
			List<Map<String, Object>> results = null;
			// 删除主表记录
			if (DBTYPE.indexOf("oracle") > -1) {
				results = exeQuerySource(selectFmOracleSql.toString(), param);
			} else if (DBTYPE.indexOf("mysql") > -1 || DBTYPE.indexOf("sqlserver") > -1) {
				results = exeQuerySource(selectFmMysqlSqlServerSql.toString(), param);
			} else {// 兼容 达梦 等其他数据库 据说和sqlserver相同
				results = exeQuerySource(selectFmMysqlSqlServerSql.toString(), param);
			}
			
			String ids = installIdToString(results,"id");
			if (Strings.isNotBlank(ids)) {
				StringBuilder delSql = new StringBuilder("delete from "+tableName+" where id in (");
				delSql.append(ids).append(")");
				exeDelQuery(delSql.toString(), null);
			}
		}
	}

	/**
	 * 删除超期定时的任务
	 * 
	 * @param objId
	 * @param type
	 * @throws Exception
	 */
	private void delJKTask(Long obj, int type) throws Exception {
		StringBuilder selectSummaryIdSql = new StringBuilder();
		StringBuilder selectAffairIdSql = new StringBuilder();
		selectSummaryIdSql.append("select id,subject from edoc_summary es where ");
		selectAffairIdSql.append("select ca.id from ctp_affair ca,edoc_summary es where ca.object_id = es.id ");
		List<Object> param = new ArrayList<Object>();
		param.add(obj);

		if (type == 1) {
			selectSummaryIdSql.append(" es.templete_id = ?");
			selectAffairIdSql.append(" and es.templete_id = ?");
		} else {
			selectSummaryIdSql.append(" es.id = ?");
			selectAffairIdSql.append(" and es.id = ?");
		}

		List<Map<String, Object>> sIds = exeQuerySource(selectSummaryIdSql.toString(), param);
		List<Map<String, Object>> aIds = exeQuerySource(selectAffairIdSql.toString(), param);
		sIds.addAll(aIds);
		for (Map<String, Object> objId : sIds) {
			Long id = Long.valueOf(objId.get("id").toString());
			String delJkJobsql = "delete from jk_job_details where job_name like '%" + id + "%'";
			String delJkSimpleTriggersql = "delete from jk_simple_triggers where trigger_name like '%" + id + "%'";
			String delJkTriggersql = "delete from jk_triggers where trigger_name like '%" + id + "%'";
			exeDelQuery(delJkJobsql, null);
			exeDelQuery(delJkSimpleTriggersql, null);
			exeDelQuery(delJkTriggersql, null);

			String subject = (String) objId.get("subject");
			if (!Strings.isBlank(subject)) {
				LOGGER.info("清除公文《" + subject + "》相关数据！");
			}
		}
	}

	/**
	 * 根据人员姓名模糊查询人员ID
	 * 
	 * @param memberName
	 * @return
	 * @throws Exception
	 */
	public Map<Long, String> getMemberIdsByName(String memberName) throws Exception {
		Map<Long, String> memberIdAndName = new HashMap<Long, String>();
		String sql = "select id,name from org_member where name like '%" + memberName + "%'";
		List<Map<String, Object>> result = exeQuerySource(sql, null);
		if (!result.isEmpty()) {
			for (Map<String, Object> map : result) {
				memberIdAndName.put(Long.valueOf(map.get("id").toString()), (String) map.get("name"));
			}
		}

		return memberIdAndName;
	}

	/**
	 * 根据人员姓名模糊查询人员ID
	 * 
	 * @param memberName
	 * @return
	 * @throws Exception
	 */
	public Map<Long, String> getTemplateNameAndIdByName(String templateName) throws Exception {
		Map<Long, String> templateIdAndName = new HashMap<Long, String>();
		String sql = "select id,subject from ctp_template where module_type in (401,402,403,404) and subject like '%"
				+ templateName + "%'";
		List<Map<String, Object>> result = exeQuerySource(sql, null);
		if (!result.isEmpty()) {
			for (Map<String, Object> map : result) {
				templateIdAndName.put(Long.valueOf(map.get("id").toString()), (String) map.get("subject"));
			}
		}

		return templateIdAndName;
	}

	public FlipInfo getEdocTemplateByTemplateName(String templateName, FlipInfo flipInfo) throws Exception {
		if (!Strings.isBlank(templateName)) {
			StringBuilder sql = new StringBuilder();
			sql.append(
					"select id,module_type,subject,org_account_id from ctp_template where module_type in (401,402,403,404) and is_system = 1 and is_delete=0 ");
			sql.append(" and subject like '%").append(templateName).append("%'");
			flipInfo = exeQueryByPage(sql.toString(), null, flipInfo.getPage(), flipInfo.getSize(), -1);
		}else {
			StringBuilder sql = new StringBuilder();
			sql.append(
					"select id,module_type,subject,org_account_id from ctp_template where module_type in (401,402,403,404) and is_system = 1 and is_delete=0 ");
			
			flipInfo = exeQueryByPage(sql.toString(), null, flipInfo.getPage(), flipInfo.getSize(), -1);
		}
		return flipInfo;
	}

	/**
	 * 根据条件筛选summary的数据
	 * @param param
	 * @return
	 * @throws Exception
	 */
	public FlipInfo getSummaryByCondition(Map<String, Object> param, FlipInfo flipInfo) throws Exception {
		if (param != null) {
			List<Object> queryParam = new ArrayList<Object>();
			StringBuilder sql = new StringBuilder();
			sql.append(
					"select id,edoc_type,doc_mark,serial_no,subject,templete_id,start_user_id,start_time,create_time from edoc_summary where govdoc_type in (1,2,3) ");
			if (param.get("templateIds") != null) {
				sql.append(" and templete_id in (").append(param.get("templateIds")).append(") ");
			}
			if (param.get("memberIds") != null) {
				sql.append(" and start_user_id in (").append(param.get("memberIds")).append(")");
			}
			if (param.get("subject") != null) {
				sql.append(" and subject like '%").append(param.get("subject")).append("%'");
			}
			if (param.get("docMark") != null) {
				sql.append(" and doc_mark like ?");
				queryParam.add("%"+param.get("docMark")+"%");
			}
			if (param.get("innerMark") != null) {
				sql.append(" and serial_no like ?");
				queryParam.add("%"+param.get("innerMark")+"%");
			}
			if (param.get("govdocType") != null) {
				sql.append(" and edoc_type = ?");
				queryParam.add(param.get("govdocType"));
			}
			if (param.get("sDate") != null) {
				sql.append(" and start_time >= ?");
				queryParam.add(param.get("sDate"));
			}
			if (param.get("eDate") != null) {
				sql.append(" and start_time <= ?");
				queryParam.add(param.get("eDate"));
			}
			sql.append(" order by start_time desc");
			flipInfo = exeQueryByPage(sql.toString(), queryParam, flipInfo.getPage(), flipInfo.getSize(), -1);

		}
		return flipInfo;
	}
	
	/**
	 *根据条件 查询待办
	 * @param param
	 * @param flipInfo
	 * @return
	 * @throws Exception
	 */
	public FlipInfo getPendingAffairByCondition(Map<String, Object> param, FlipInfo flipInfo) throws Exception {
		if (param != null) {
			List<Object> queryParam = new ArrayList<Object>();
			StringBuilder sql = new StringBuilder();
			sql.append(
					"select affair.id,affair.subject,affair.create_date,member.name from ctp_affair affair,org_member member where affair.member_id = member.id and affair.app = 4 and affair.state = 3 ");
			if (param.get("memberIds") != null) {
				sql.append(" and affair.member_id in (").append(param.get("memberIds")).append(")");
			}
			if (param.get("subject") != null) {
				sql.append(" and affair.subject like '%").append(param.get("subject")).append("%'");
			}
			if (param.get("sDate") != null) {
				sql.append(" and affair.create_date >= ?");
				queryParam.add(param.get("sDate"));
			}
			if (param.get("eDate") != null) {
				sql.append(" and affair.create_date <= ?");
				queryParam.add(param.get("eDate"));
			}
			sql.append(" order by affair.create_date desc");
			flipInfo = exeQueryByPage(sql.toString(), queryParam, flipInfo.getPage(), flipInfo.getSize(), -1);
		}
		return flipInfo;
	}

	public static List<Map<String, Object>> getSummaryFormIdAndSummaryId(String summaryIds) throws Exception {
		List<Map<String, Object>> result = new ArrayList<Map<String, Object>>();
		if (!Strings.isBlank(summaryIds)) {
			List<Object> queryParam = new ArrayList<Object>();
			queryParam.add(summaryIds);
			StringBuilder sql = new StringBuilder("select id,form_app_id from edoc_summary where id in (");
			sql.append(summaryIds).append(")");
			result = exeQuerySource(sql.toString(),null);
		}
		return result;
	}
	
	/**
	 * 统计模板所产生的公文数量
	 * @param templateId
	 * @return
	 * @throws Exception
	 */
	public static Integer countEdocSummaryByTemplateId(Long templateId) throws Exception {
		Integer result = 0;
		if(templateId != null) {
			List<Object> queryParam = new ArrayList<Object>();
			queryParam.add(templateId);
			String countSql = "select count(id) id from edoc_summary where templete_id = ?";
			List<Map<String, Object>> queryRes = exeQuerySource(countSql,queryParam);
			return Integer.valueOf(String.valueOf(queryRes.get(0).get("id")));
		}

		return result;
	}
	/**
	 * 统计模板所产生的公文数量
	 * @param templateId
	 * @return
	 * @throws Exception
	 */
	public static List<Long> getEdocSummaryIdByTemplateId(Long templateId) throws Exception {
		List<Long> list = new ArrayList<Long>();
		if(templateId != null) {
			List<Object> queryParam = new ArrayList<Object>();
			
			queryParam.add(templateId);
			String countSql = "select id from edoc_summary where templete_id = ?";
			List<Map<String, Object>> queryRes = exeQuerySource(countSql,queryParam);
			for(Map map :queryRes) {
				list.add(Long.valueOf(String.valueOf(map.get("id"))));
			}
			return list;
		}

		return list;
	}
	/**
	 * 修改affair表中的文号信息
	 * @param summaryId
	 * @param docMark
	 * @throws BusinessException 
	 * @throws Exception
	 */
	public void replaceAffairEdocMark(EdocSummary summary, String docMark) throws BusinessException {
		List<CtpAffair> affairs = affairManager.getAffairs(summary.getId());
		for (CtpAffair affair : affairs) {
			Map<String,Object> map = AffairUtil.getExtProperty(affair);
			map.put(AffairExtPropEnums.edoc_edocMark.name(), docMark);
			AffairUtil.setExtProperty(affair, map);
		}
		affairManager.updateAffairs(affairs);
	}
	
	/**
	 * 修改summary表中的文号信息
	 * @param summaryId
	 * @param docMark
	 * @throws Exception
	 */
	public void replaceSummaryEdocMark(Long summaryId,String docMark) throws Exception{
		String reSummaryMarkSql = "update edoc_summary set doc_mark = '"+docMark+"' where id = "+summaryId;
		exeDelQuery(reSummaryMarkSql,null);
	}
	
	/**
	 * 传入发文ID，返回发文产生的收文数据ID
	 * @param summaryId
	 * @return
	 * @throws Exception
	 */
	public List getRecIdsBySendId(Long summaryId) throws Exception{
		List<Object> ids = new ArrayList<Object>();
		List<Object> queryParam = new ArrayList<Object>();
		queryParam.add(summaryId);
		String exchangeMainIdSql = "select main.id from edoc_summary summary,govdoc_exchange_main main where summary.id = main.summary_id and main.exchange_type = 0 and summary.id = ?";
		List<Map<String, Object>> exchangeMainIds = exeQuerySource(exchangeMainIdSql, queryParam);
		String mainIds = installIdToString(exchangeMainIds, "id");
		List<Object> mainIdsParam = new ArrayList<Object>();
		mainIdsParam.add(mainIds.toString());
		if (!Strings.isBlank(mainIds)) {
			// 处理生成的收文数据ID
			String recSummaryIdsSql = "select rec_summary_id from govdoc_exchange_detail where main_id = ?";
			List<Map<String, Object>> recSummaryIds = exeQuerySource(recSummaryIdsSql, mainIdsParam);
			ids = installIdToList(recSummaryIds, "rec_summary_id");
			String summaryIdsSql = "select summary_id from govdoc_exchange_detail where main_id = ?";
			List<Map<String, Object>> summaryIds = exeQuerySource(summaryIdsSql, mainIdsParam);
			ids.addAll(installIdToList(summaryIds, "summary_id"));
		}
		return ids;
	}
	
	/**
	 * 待办置已办
	 * @param affairId
	 * @throws Exception
	 */
	public void exAffairToDone(String affairId) throws Exception{
		StringBuilder sql  = new StringBuilder();
		sql.append("update CtpAffair set state = 4,completeTime = :completeTime where id in (").append(affairId).append(")");
		Map<String, Object> paramMap = new HashMap<String, Object>();
		paramMap.put("completeTime", new Date());
		DBAgent.bulkUpdate(sql.toString(), paramMap);
	}
	
	/**
	 * 根据summaryId更新所有相关affair的正文类型
	 * @param summaryId
	 * @param bodyType
	 * @throws Exception
	 */
	public void updateAffairBodyType(Long summaryId,String bodyType) throws Exception{
		List<Object> param = new ArrayList<Object>();
		String sql = "update ctp_affair set body_type = ? where object_id = ? ";
		param.add(bodyType);
		param.add(summaryId);
		
		exeDelQuery(sql,param);
		
	}

	private String installIdToString(List<Map<String, Object>> data, String symbol) {
		StringBuilder res = new StringBuilder();
		if (!data.isEmpty()) {
			for (int i = 0; i < data.size(); i++) {
				res.append(data.get(i).get(symbol));
				if (i + 1 < data.size()) {
					res.append(",");
				}
			}
		}

		return res.toString();
	}
	
	private List installIdToList(List<Map<String, Object>> data, String symbol) {
		List<Object> res = new ArrayList<Object>();
		if (!data.isEmpty()) {
			for (int i = 0; i < data.size(); i++) {
				res.add(data.get(i).get(symbol));
			}
		}

		return res;
	}

	private static FlipInfo exeQueryByPage(String sql, List params, int page, int pageSize, int total) {
		JDBCAgent dba = new JDBCAgent();
		FlipInfo fpi = new FlipInfo();
		if (total < 0) {// 只取一次总数
			fpi.setNeedTotal(true);
		} else {
			fpi.setTotal(total);
			fpi.setNeedTotal(false);
		}
		fpi.setPage(page);
		fpi.setSize(pageSize);
		try {
			if (params == null) {
				dba.findByPaging(sql, fpi);
			} else {
				dba.findByPaging(sql, params, fpi);
			}
		} catch (Throwable e) {
			LOGGER.error("执行分页查询失败...", e);
		} finally {
			dba.close();
		}
		return fpi;
	}

	private void exeBulkDelQuery(List<String> sqlLIst, List params) throws Exception {
		for (String sql : sqlLIst) {
			exeDelQuery(sql, params);
		}
	}
	
	private void exeBulkDelQueryForIn(List<String> sqlLIst, String param) throws Exception {
		for (String sql : sqlLIst) {
			sql = sql.replace("?", param);
			exeDelQuery(sql, null);
		}
		if (DBTYPE.indexOf("oracle") > -1) {
			StringBuilder delSsql = new StringBuilder("delete from edoc_summary where id in (");
			delSsql.append(param).append(")");
			exeDelQuery(delSsql.toString(), null);
		}
	}

	private void exeDelQuery(String sql, List params) throws Exception {
		JDBCAgent jdbcAgent = new JDBCAgent();
		try {
			if (Strings.isNotEmpty(params)) {
				jdbcAgent.execute(sql,params);
			} else {
				jdbcAgent.execute(sql);
			}
		} catch (Exception e) {
			throw e;
		} finally {
			jdbcAgent.close();
		}

	}

	private static List<Map<String, Object>> exeQuerySource(String sql, List params) throws Exception {
		List<Map<String, Object>> result = new ArrayList<Map<String, Object>>();
		JDBCAgent jdbcAgent = new JDBCAgent();
		try {
			if (Strings.isNotEmpty(params)) {
				jdbcAgent.execute(sql,params);
			} else {
				jdbcAgent.execute(sql);
			}
			result = (List<Map<String, Object>>) jdbcAgent.resultSetToList();
		} catch (Exception e) {
			throw e;
		} finally {
			jdbcAgent.close();
		}
		return result;
	}
	

	/**
	 * 获取当前数据库类型
	 * 
	 * @return
	 */
	private static String getDbType() {
		JDBCAgent agent = new JDBCAgent(true);
		String dbType = agent.getDBType().toLowerCase();
		agent.close();
		return dbType;
	}

	/**
	 * 获取xml的根节点
	 * 
	 * @param xml
	 * @return
	 */
	public static Element getRootElementByString(String xml) {
		if (Strings.isBlank(xml))
			return null;
		try {
			SAXReader reader = new SAXReader();
			Document doc = reader.read(new InputSource(new ByteArrayInputStream(xml.trim().getBytes("utf-8"))));
			return doc.getRootElement();
		} catch (Exception e) {

		}
		return null;
	}
	/**
	 * 获取templateName
	 * 
	 * @param id
	 * @return 
	 */
	public String getTemplateNameById(Object id) throws Exception{
		StringBuilder sql  = new StringBuilder();
		List<Object> param = new ArrayList<Object>();
		param.add(id);
		sql.append("select subject from ctp_template where id = ?");
		List<Map<String,Object>> result = exeQuerySource(sql.toString(),param);
		return installIdToString(result, "subject");
	}
	/**
	 * 校验文号是否被占用和预留
	 * 
	 * @param docMark
	 * @return 
	 */
	public String isHaveDocMarkByMarkName(String docMark)throws Exception{
		StringBuilder sql = new StringBuilder();
		Map<String, Object> paramMap = new HashMap<String, Object>();
		paramMap.put("docMark", docMark);
		sql.append(" from EdocMarkHistory where docMark =:docMark ");
		int count = DBAgent.count(sql.toString(), paramMap);
		return String.valueOf(count);
	}
	/**
	 * 校验文号是否被使用
	 * 
	 * @param docMark
	 * @return 
	 */
	public String isHasDocMarkByMarkName(String docMark)throws Exception{
		StringBuilder sql  = new StringBuilder();
		List<Object> param = new ArrayList<Object>();
		param.add(docMark);
		sql.append("select count(*) total from edoc_mark where doc_mark = '?' ");
		List<Map<String,Object>> result = exeQuerySource(sql.toString(),param);
		return installIdToString(result,"total");
		
	}
	/**
	 * 根据summaryId得到fileID
	 * 
	 * @param oriSummaryId
	 * @return 
	 */
	public Long getFileIdBySummaryId(Long oriSummaryId)throws Exception{
		StringBuilder sql  = new StringBuilder();
		List<Object> param = new ArrayList<Object>();
		param.add(oriSummaryId);
		sql.append("select content from ctp_content_all where module_id = ? and content_type != 20");
		List<Map<String,Object>> result = exeQuerySource(sql.toString(),param);
		return Long.valueOf(installIdToString(result,"content"));
		
	}
	

	/**
	 * 公文处理强制撤销
	 * 
	 * @param LIST<Long>SummaryId
	 * @return 
	 */
	public int cancelProcessForEdoc(EdocSummary summary) throws Exception{
		List<Long> params = new ArrayList<Long>();
		params.add(summary.getId());
		 // 处理收藏,交换登记,收文
        // 追加处理公文的收藏文档删除脚本
		Long summaryId= summary.getId();
		int govdocType= summary.getGovdocType();
		int result = uodoprocess(summary);
		if(result == -1 || result == 1 || result == -2){
			return 1;
		}
        appendColEdocDocDelSqls(params);
        /*// 追加处理公文督办信息
        appendEdocSupDelSqls(sql,id);*/       
        	//撤销的是发文
        //普通交换
    	List<Map<String , Object>> results = exeQuerySource("select detail.summary_id,detail.rec_summary_id from govdoc_exchange_main main,govdoc_exchange_detail detail where detail.main_id = main.id and main.exchange_type = 0 and main.summary_id = ?", params);
    	String recSummaryId = installIdToString(results,"rec_summary_id");
    	String exchangeSummaryId = installIdToString(results,"summary_id");
		if(!"null".equals(recSummaryId) && !"".equals(recSummaryId)){
			recSummaryId += "," + exchangeSummaryId;
			List<Long> summaryIdList = new ArrayList<Long>();
			for(String string : recSummaryId.split(",")){
				summaryIdList.add(Long.valueOf(string));
			}
			govdocMarkManager.transCancelForMark(summaryIdList, false);
			//撤销发文有收文数据（电子收文数据）
			//删除收文产生的相关公文数据
			List<Map<String, Object>> recDateFrom = getSummaryFormIdAndSummaryId(recSummaryId);
			deleteEdocDataBySummary(recDateFrom);
		}
		//联合发文
    	List<Map<String , Object>> lianhefawenresults = exeQuerySource("select detail.summary_id from govdoc_exchange_main main,govdoc_exchange_detail detail where detail.main_id = main.id and main.exchange_type = 1 and main.summary_id = ?", params);
    	String lianhefawenSummaryId = installIdToString(lianhefawenresults,"summary_id");
    	if (Strings.isNotBlank(lianhefawenSummaryId)) {
    		String[] lianhefawenSummaryIdArr = lianhefawenSummaryId.split(",");
			List<Long> summaryIdList = new ArrayList<Long>();
			for(String string : lianhefawenSummaryIdArr){
				summaryIdList.add(Long.valueOf(string));
			}
			govdocMarkManager.transCancelForMark(summaryIdList, false);
			//撤销发文有收文数据（电子收文数据）
			//删除收文产生的相关公文数据
			List<Map<String, Object>> recDateFrom = getSummaryFormIdAndSummaryId(lianhefawenSummaryId);
			deleteEdocDataBySummary(recDateFrom);
		}
    	//更新交换状态
		updateSwapStatus(govdocType,summaryId);
        //撤销后删除所有续办节点
		govdocContinueManager.deleteAllCustomDealWidth(summaryId);
		//撤销后释放所有在本公文中被使用的编号
		govdocPishiManager.emptyPishiNo(summaryId);
		return 0;
	}
	
	//更新交换状态
	private void updateSwapStatus(int govdocType,Long summaryId) {
		try {
			//公文交换或联合发文
			if (govdocType == ApplicationSubCategoryEnum.edoc_fawen.getKey()) {
				GovdocExchangeMain main = govdocExchangeManager.findBySummaryId(summaryId, 0);
				if (main != null) {
					List<GovdocExchangeDetail> details = govdocExchangeManager.getDetailByMainId(main.getId());
					for (GovdocExchangeDetail govdocExchangeDetail : details) {
						govdocExchangeManager.exchangeCancel(govdocExchangeDetail.getId(), ResourceUtil.getString("govdoc.revocationProcess.forced.S1"));
					}
				}
				main = govdocExchangeManager.findBySummaryId(summaryId, 1);
				if (main != null) {
					List<GovdocExchangeDetail> details = govdocExchangeManager.getDetailByMainId(main.getId());
					for (GovdocExchangeDetail govdocExchangeDetail : details) {
						govdocExchangeManager.exchangeCancel(govdocExchangeDetail.getId(), ResourceUtil.getString("govdoc.revocationProcess.forced.S1"));
					}
				}
			} else if(govdocType == ApplicationSubCategoryEnum.edoc_shouwen.getKey()){
				GovdocExchangeDetail detail = govdocExchangeManager.findDetailByRecSummaryId(summaryId);
				if (detail != null) {
					govdocExchangeManager.recSummaryCancelUpdateExchangeStatus(detail.getId(), ResourceUtil.getString("govdoc.revocationProcess.forced.S1"));
				}
			}
		} catch (Exception e) {
			LOGGER.error("更新交换状态异常",e);
		}
	}

	//撤销公文
	private int uodoprocess(EdocSummary summary) {
		// TODO Auto-generated method stub
		try {
			List<Long> params = new ArrayList<Long>();
			params.add(summary.getId());
			//得到流程实例ID
			Long caseId = summary.getCaseId();
			GovdocRepealVO repealVO = new GovdocRepealVO();
			User user = new User();
			List<Map<String , Object>> returnSource = exeQuerySource("select id,member_id from ctp_affair where state = 2 and object_id = ?", params);
			String memberId = installIdToString(returnSource, "member_id");
			user.setId(Long.valueOf(memberId));
			AppContext.putThreadContext(GlobalNames.SESSION_CONTEXT_USERINFO_KEY, user);
			repealVO.setCurrentUser(user);		
			repealVO.setRepealComment(ResourceUtil.getString("govdoc.revocationProcess.forced.S1"));
			//是否追溯流程
			repealVO.setIsWFTrace("0");
			//开始撤销流程			
			List<Map<String , Object>> returnSources = exeQuerySource("select state from edoc_summary where id = ?", params);
			String affairId = installIdToString(returnSource, "id");
			String state = installIdToString(returnSources, "state");
			repealVO.setAffairId(Long.valueOf(affairId));
			repealVO.setSummaryId(Long.valueOf(summary.getId()));
			AffairData affairData = GovdocAffairHelper.getRepealAffairData(summary.getId(), Long.valueOf(affairId), repealVO);
			affairData.setFormRecordId(summary.getFormRecordid());
			affairData.addBusinessData(GovdocWorkflowEventListener.CURRENTUSER_CONSTANT, repealVO.getCurrentUser());
			if("3".equals(state) || "1".equals(state)){
				return govdocWorkflowManager.cancelCase(affairData, caseId ,true,summary);
			}else{
				return govdocWorkflowManager.cancelCase(affairData, caseId ,false,summary);
			}			
		} catch (Exception e) {
			LOGGER.error("撤销公文出现异常",e);
		}
		return 0;			
	}

	//删除交换数据的脚本
	private void appendEdocDelExchangeSqls(List<Long> params) {
		// TODO Auto-generated method stub
		try {
			//公文统计表删除
			exeDelQuery("delete from edoc_stat where edoc_id = ?", params);
			// 发文关联收文(收关联发文,发关联收文)
			exeDelQuery("delete from edoc_summary_relation where summary_id = ?", params);
			exeDelQuery("delete from edoc_summary_relation where relation_edoc_id = ?", params);
			List<Map<String, Object>> result = exeQuerySource("select ged.summary_id from govdoc_exchange_main gem,govdoc_exchange_detail ged where ged.main_id = gem.id and gem.summary_id = ?", params);		
			//删除交换的公文
			List<Map<String, Object>> recDateFrom = getSummaryFormIdAndSummaryId(installIdToString(result, "summary_id"));
			deleteEdocDataBySummary(recDateFrom);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			LOGGER.error("删除交换数据sql执行错误",e);
		}
				
	}

	//删除公文督办信息脚本
	private void appendEdocSupDelSqls(Long id) {
		// TODO Auto-generated method stub
		List<Long> params = new ArrayList<Long>();
		params.add(id);
		if(DBTYPE.indexOf("oracle") > -1){
            try {
				exeDelQuery( "delete from ctp_supervise_receiver csr where exists (select 1 from ctp_supervise_log csl, "
                        + "ctp_supervise_detail csd where csr.log_id = csl.id and "
                        + "csl.supervise_id = csd.id and csd.entity_id = ?)", params);
				exeDelQuery( "delete from ctp_supervise_log csl where exists (select 1 from ctp_supervise_detail csd "
                        + " where csl.supervise_id = csd.id and csd.entity_id = ?)", params);
				exeDelQuery( "delete from ctp_supervisor css where exists(select 1 from ctp_supervise_detail csd "
                        + " where css.supervise_id = csd.id and csd.entity_id = ?)", params);
				exeDelQuery( "delete from ctp_supervise_detail where entity_id = ?", params);
			} catch (Exception e) {
				LOGGER.error("执行SQL出错",e);
			}
		}else if(DBTYPE.indexOf("mysql") > -1 || DBTYPE.indexOf("sqlserver") > -1){
	            try {
	            	exeDelQuery("delete csr from ctp_supervise_receiver csr, ctp_supervise_log csl, ctp_supervise_detail csd, "
	                        + "edoc_summary cs where csr.log_id = csl.id and csl.supervise_id = csd.id and "
	                        + "csd.entity_id = cs.id and cs.id = ?", params);
	            	exeDelQuery("delete csl from ctp_supervise_log csl, ctp_supervise_detail csd, edoc_summary cs where "
	                        + "csl.supervise_id = csd.id and csd.entity_id = cs.id and cs.id = ?", params);
	            	exeDelQuery("delete css from ctp_supervisor css, ctp_supervise_detail csd, edoc_summary cs where cs.id = "
	                        + "csd.entity_id and csd.id = css.supervise_id and cs.id = ?", params);
	            	exeDelQuery("delete csd from ctp_supervise_detail csd, edoc_summary cs where csd.entity_id = cs.id "
	                        + "and cs.id = ?", params);
				} catch (Exception e) {
					LOGGER.error("执行SQL出错",e);
				}
		}else{
	            try {
					exeDelQuery("delete from ctp_supervise_receiver csr using ctp_supervise_log csl, ctp_supervise_detail "
	                        + "csd, edoc_summary cs where csr.log_id = csl.id and csl.supervise_id = csd.id "
	                        + "and csd.entity_id = cs.id and cs.id = ?", params);
					exeDelQuery("delete from ctp_supervise_log csl using ctp_supervise_detail csd, edoc_summary cs where "
	                        + "csl.supervise_id = csd.id and csd.entity_id = cs.id and cs.id = ?", params);
					exeDelQuery("delete from ctp_supervisor css using ctp_supervise_detail csd, edoc_summary cs where "
	                        + "css.supervise_id = csd.id and csd.entity_id = cs.id and cs.id = ?", params);
					exeDelQuery("delete from ctp_supervise_detail csd using edoc_summary cs where csd.entity_id = cs.id "
	                        + "and cs.id = ?", params);
				} catch (Exception e) {
					LOGGER.error("执行SQL出错",e);
				}
		}
	}
	//公文的收藏文档删除脚本
	private void appendColEdocDocDelSqls(List<Long> params) {
		// TODO Auto-generated method stub
		if(DBTYPE.indexOf("oracle") > -1){
	            try {
					exeDelQuery( "delete from doc_learning dl where exists (select 1 from doc_resources dr, "
                            + "ctp_affair ca where dl.doc_resource_id = dr.id and dr.source_id = "
                            + "ca.id and ca.object_id = ?)", params);
					exeDelQuery( "delete from doc_learning dl where exists (select 1 from doc_resources dr where dl.doc_resource_id "
                            + "= dr.id and dr.source_id = ?)", params);
					exeDelQuery( "delete from doc_favorites df where exists (select 1 from doc_resources dr, "
                            + "ctp_affair ca where df.doc_resource_id = dr.id and dr.source_id = "
                            + "ca.id and ca.object_id = ?)", params);
					exeDelQuery( "delete from doc_favorites df where exists (select 1 from doc_resources dr, "
                            + "ctp_affair ca where df.doc_resource_id = dr.id and dr.source_id = "
                            + "ca.id and ca.object_id = ?)", params);
					exeDelQuery( "delete from doc_resources drm where exists (select 1 from doc_resources dr where drm.source_id = "
                            + "dr.id and dr.source_id = ?)", params);
					exeDelQuery( "delete from doc_resources where source_id = ? ", params);
					exeDelQuery( "delete from doc_resources drm where exists (select 1 from doc_resources dr,ctp_affair ca where drm.source_id = "
                            + "dr.id and dr.source_id = ca.id and ca.object_id = ?)", params);
				} catch (Exception e) {
					LOGGER.error("执行SQL出错",e);
				}
		}else if(DBTYPE.indexOf("mysql") > -1 || DBTYPE.indexOf("sqlserver") > -1){
	            try {
	            	exeDelQuery("delete dl from doc_learning dl, doc_resources dr, ctp_affair ca where dl.doc_resource_id = dr.id "
                            + "and dr.source_id = ca.id and ca.object_id = ?", params);
	            	exeDelQuery("delete dl from doc_learning dl, doc_resources dr where dl.doc_resource_id = "
                            + "dr.id and dr.source_id = ?", params);
	            	exeDelQuery("delete df from doc_favorites df, doc_resources dr, ctp_affair ca where df.doc_resource_id = "
                            + "dr.id and dr.source_id = ca.id and ca.object_id = ?", params);
	            	exeDelQuery("delete df from doc_favorites df, doc_resources dr where df.doc_resource_id = "
                            + "dr.id and dr.source_id = ?", params);
	            	exeDelQuery("delete drm from doc_resources drm, doc_resources dr where drm.source_id = dr.id "
                            + "and dr.source_id = ?", params);
					exeDelQuery("delete from doc_resources where source_id = ?", params);
					exeDelQuery("delete dr from doc_resources dr,ctp_affair ca where dr.source_id = ca.id and ca.object_id = ?", params);
				} catch (Exception e) {
					LOGGER.error("执行SQL出错",e);
				}
		}else{
	            try {
					exeDelQuery("delete from doc_learning dl using doc_resources dr, ctp_affair ca "
                            + "where dl.doc_resource_id = dr.id and dr.source_id = ca.id and ca.object_id = ?", params);
					exeDelQuery("delete from doc_learning dl using doc_resources dr where dl.doc_resource_id = dr.id "
                            + "and dr.source_id = ?", params);
					exeDelQuery("delete from doc_favorites df using doc_resources dr, ctp_affair ca where df.doc_resource_id = "
                            + "dr.id and dr.source_id = ca.id and ca.object_id = ?", params);
					exeDelQuery("delete from doc_favorites df using doc_resources dr where df.doc_resource_id = dr.id "
                            + "and dr.source_id = ?;", params);
					exeDelQuery("delete from doc_resources drm using doc_resources dr where drm.source_id = dr.id "
                            + "and dr.source_id = ?", params);
					exeDelQuery("delete from doc_resources where source_id = ?", params);
					exeDelQuery("delete dr from doc_resources dr,ctp_affair ca where dr.source_id = ca.id and ca.object_id = ?", params);
				} catch (Exception e) {
					LOGGER.error("执行SQL出错",e);
				}
		}
	}

	public FlipInfo getSentAffairByCondition(Map<String, Object> param, FlipInfo flipInfo) {
		if (param != null) {
			List<Object> queryParam = new ArrayList<Object>();
			StringBuilder sql = new StringBuilder();
			sql.append(
					"select affair.id,affair.subject,affair.create_date,summary.start_user_id,summary.send_to,copy_to,report_to from ctp_affair affair,edoc_summary summary where affair.object_id = summary.id and affair.app = 4 and sub_app in (1,2,3) and affair.state = 2 and summary.is_quick_send = 0 ");
			if (param.get("memberIds") != null) {
				sql.append(" and affair.sender_id in (").append(param.get("memberIds")).append(")");
			}
			if (param.get("subject") != null) {
				sql.append(" and affair.subject like '%").append(param.get("subject")).append("%'");
			}
			if (param.get("sDate") != null) {
				sql.append(" and affair.create_date >= ?");
				queryParam.add(param.get("sDate"));
			}
			if (param.get("eDate") != null) {
				sql.append(" and affair.create_date <= ?");
				queryParam.add(param.get("eDate"));
			}
			sql.append(" order by affair.create_date desc");
			flipInfo = exeQueryByPage(sql.toString(), queryParam, flipInfo.getPage(), flipInfo.getSize(), -1);
		}
		return flipInfo;
	}
}


